==> checkstyle_5.9.orig.tar.gz: checkstyle-5.9/src/main/java/com/puppycrawl/tools/checkstyle/PropertyResolver.java <==
////////////////////////////////////////////////////////////////////////////////
// checkstyle: Checks Java source code for adherence to a set of rules.
// Copyright (C) 2001-2014  Oliver Burn
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////////
package com.puppycrawl.tools.checkstyle;

import com.puppycrawl.tools.checkstyle.api.CheckstyleException;

/**
 * Resolves properties in module configurations.
 *
 * The {@link ConfigurationLoader} uses a PropertyResolver to
 * resolve the values of external properties like <code>${basename}</code>
 * that occur in the configuration file.
 *
 * @see ConfigurationLoader
 * @author lkuehne
 */
public interface PropertyResolver
{
    /**
     * Resolves a property name to it's value.
     * @param aName the name of the property.
     * @return the value that is associated with <code>propertyName</code>.
     * @throws CheckstyleException if the propertyName cannot be reolved
     */
    String resolve(String aName)
        throws CheckstyleException;
}

==> checkstyle_6.13.orig.tar.gz: checkstyle-6.13/src/main/java/com/puppycrawl/tools/checkstyle/PropertyResolver.java <==
////////////////////////////////////////////////////////////////////////////////
// checkstyle: Checks Java source code for adherence to a set of rules.
// Copyright (C) 2001-2015 the original author or authors.
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////////

package com.puppycrawl.tools.checkstyle;

/**
 * Resolves properties in module configurations.
 *
 * <p>The {@link ConfigurationLoader} uses a PropertyResolver to
 * resolve the values of external properties like {@code ${basename}}
 * that occur in the configuration file.
 *
 * @author lkuehne
 * @see ConfigurationLoader
 */
public interface PropertyResolver {
    /**
     * Resolves a property name to it's value.
     * @param name the name of the property.
     * @return the value that is associated with {@code propertyName}.
     */
    String resolve(String name);
}
